function handleSettings(settingsPage, successFunction) {
    return function (e) {
      $("#overlay").show();
      var doSubmit = true;
      $(".ui-accordion-content").each(function () {
          e.preventDefault();
          var errorList = $(this).find(".parsley-error, .validation-error");
          var ignoreValidationError = true; // Ignore validation errors for disabled fields
          var i;
          for (i = 0; i < errorList.length ; i++) {
              var element = $(errorList[i]).children();
              if (isFieldDisabled(element) == false){
                  ignoreValidationError = false; // Enabled field with validation error found
                  break;
              }
          }
          if (errorList.length > 0 && ignoreValidationError == false) {
              $(this).slideDown();
              doSubmit = false;
          }
      });

      var serialized_form = $( this ).serialize();
      $.when($.getStartTime()).done(function(ref_start_time) {
          if (doSubmit === true) {
              $.ajax(
                settingsPage,
                  {
                      method: "POST",
                      data: serialized_form,
                      success: function(data) {
                          $.waitForApp(successFunction, 5000, ref_start_time);
                      },
                      error: function(error) {
                          alert("Could not save settings")
                          $("#overlay").hide();
                      }
                  }
              );
          } else {
              $("#overlay").hide();
          }
      });

  }
}

/*global $, alert */
$(function () {
    "use strict";
    /* INIT */
    var disable_enable = function (checkbox) {
        var checkbox_id = checkbox.attr("id"),
            $sibling_inputs = checkbox.parents("fieldset").find("input").filter("[enable_disable_by='" + checkbox_id + "']"),
            $filtered_sibling_inputs = $(""),
            checked = checkbox.is(":checked"),
            $parent_checkbox;
        if (typeof checkbox.attr("enable_disable_by") !== "undefined") {
            $parent_checkbox = $("#" + checkbox.attr("enable_disable_by"));
            if (!$parent_checkbox.is(":checked")) {
                // Stop sublevel enable_disable to show their inputs on init.
                return;
            }
        }
        $sibling_inputs.each(function (){
            var sublevel_checked,
                $sublevel_sibling_inputs;
            if ($(this).hasClass("enable-disable")) {
                sublevel_checked = $(this).is(":checked");
                $sublevel_sibling_inputs = $("[enable_disable_by='" + $(this).attr("id") + "']");
                if ((sublevel_checked && checked) || (!checked)) {
                    $filtered_sibling_inputs = $filtered_sibling_inputs.add($sublevel_sibling_inputs);
                }
                // TODO Add recursion to allow for more than one sublevel of enable_disable
            }
            $filtered_sibling_inputs = $filtered_sibling_inputs.add($(this));
        });
        if (checked) {
            $filtered_sibling_inputs.parent().parent(".ctrlHolder").slideDown();
        } else {
            $filtered_sibling_inputs.parent().parent(".ctrlHolder").slideUp();
        }
    };
    $("#form-settings .enable-disable").each(function() {
        disable_enable($(this));
    });

    $("#left form div.accordify").accordion({
        heightStyle: "content",
        icons: false
    });
    $("#form-settings input").each(function () {
        var name = $(this).attr("name");
        $(this).attr("data-parsley-class-handler", "#validation-wrapper-" + name);
    });

    // Submit click event
    $("#left form").submit(handleSettings("settings.html", function(){location.reload()}));

    function isFieldDisabled(field){
        var enableDisableBy=$(field).attr('enable_disable_by');
        while (typeof enableDisableBy !=='undefined'){
            if ($('#' + enableDisableBy).is(':checked') == false){
                return true; // Element is considered disabled if disabled on any level above
            }
            enableDisableBy = $('#' + enableDisableBy).attr('enable_disable_by')
        }
        return false; // Element is considered enabled if not disabled on any level above
    }

    $("#form-settings .enable-disable").click(function () {
        disable_enable($(this));
    });
    $("#right .centered").createVideo();

    var $meta_warning;
    var $meta_error;
    var inch2cm = 2.54;
    var cm2inch = 1 / inch2cm;
    $("#meta_height").on('keyup', function() {
        if ( $meta_warning ) {
            $meta_warning.remove();
        }
        if ( $meta_error ) {
            $(this).parent(".validationWrapper").removeClass("validation-error");
            $meta_error.remove();
        }
        var val = parseInt($(this).val(), 10);
        var units = document.getElementById("meta_height_units");
        var unitsval = units.options[units.selectedIndex].value;
        var factor = 1;
        if (unitsval === "inch") {
            factor = cm2inch;
        }
        if ( val < parseInt(210*factor) || val > parseInt(450*factor) ) {
            $(this).parent(".validationWrapper").addClass("validation-error");
            $meta_error = $(
            '<ul class="parsley-errors-list filled" id="parsley-id-9">' +
                '<li class="parsley-range">This value should be between ' + parseInt(210*factor) + ' and ' + parseInt(450*factor) + '.</li>' +
            '</ul>'
            ).insertAfter("#meta_height");
        }
        if ( val < parseInt(240*factor) && val >= parseInt(210*factor) ) {
            $meta_warning = $("<p/>").insertAfter("#meta_height").addClass("parsley-warning");
            $meta_warning.text("Note that heights below " + parseInt(240*factor) + " are not supported.").show();
        }
        if ( val > parseInt(400*factor) && val <= parseInt(450*factor) ) {
            $meta_warning = $("<p/>").insertAfter("#meta_height").addClass("parsley-warning");
            $meta_warning.text("Note that heights above " + parseInt(400*factor) + " are not supported.").show();
        }
    }).trigger("keyup");

    $("#meta_height_units").on("change",function() {
        var unitsval = this.value;
        var meta_height = document.getElementById("meta_height");
        if (unitsval === "inch") {
            meta_height.value = Math.round(meta_height.value * cm2inch);
        }
        if (unitsval === "cm") {
            meta_height.value = Math.round(meta_height.value * inch2cm);
        }
    });

});
